@@ -17,7 +17,7 @@ extern void fio_gettime(struct timeval *, void *);
 extern void fio_gtod_init(void);
 extern void fio_clock_init(void);
 extern int fio_start_gtod_thread(void);
-extern int fio_monotonic_clocktest(void);
+extern int fio_monotonic_clocktest(int debug);
 extern void fio_local_clock_init(int);
 
 extern struct timeval *fio_tv;
